/*
 Copyright 2004-2008 Paul R. Holser, Jr.  All rights reserved.
 Licensed under the Academic Free License version 3.0
 */

package jaggregate.internal;

import static java.lang.String.format;

/**
 * Constants and methods used internally for performing checks on method arguments.
 *
 * @author <a href="mailto:pholser@alumni.rice.edu">Paul Holser</a>
 * @version $Id: ArgumentChecks.java,v 1.2 2008/03/30 03:07:11 pholser Exp $
 */
public class ArgumentChecks {
    public static final String DISCRIMINATOR = "discriminator";
    public static final String OPERATION = "operation";
    public static final String TRANSFORMER = "transformer";
    public static final String EMPTY_SEQUENCE = "empty sequence";
    public static final String REPLACEMENT_SEQUENCE = "replacement sequence";
    public static final String SEQUENCE = "sequence";
    public static final String COLLECTION = "collection";
    public static final String MAPPER = "mapper";
    public static final String STARTING_INDEX = "starting";
    public static final String ENDING_INDEX = "ending";
    public static final String ADDITION_INDEX = "addition";
    public static final String NEGATIVE_AMOUNT = "illegal negative amount: ";
    public static final String EXPECTED_SEQUENCE_SIZE =
        "expecting sequence to have size ";
    public static final String BUT_WAS = ", was ";
    public static final String ITERABLE = "iterable";
    private static final String NULL_FORMAT = "illegal null %1$s";

    /**
     * Discourages instantiation.
     *
     * @throws UnsupportedOperationException always
     */
    protected ArgumentChecks() {
        throw new UnsupportedOperationException();
    }

    /**
     * Raises an exception with the given failure message if the given object is
     * {@code null}.
     *
     * @param target object to check
     * @param failureMessage message to populate the exception with if {@code target}
     * is {@code null}
     * @throws NullPointerException if {@code target} is {@code null}
     */
    public static void checkNotNull( Object target, String failureMessage ) {
        if ( target == null )
            throw new NullPointerException( format( NULL_FORMAT, failureMessage ) );
    }
}
