/*
 Copyright 2004-2008 Paul R. Holser, Jr.  All rights reserved.
 Licensed under the Academic Free License version 3.0
 */

package jaggregate.junit.framework;

import static java.lang.String.format;

import jaggregate.UnaryPredicate;
import static junit.framework.Assert.*;

/**
 * Additional assertions for <a href="http://www.junit.org">JUnit</a> that apply to
 * Java objects in general.
 *
 * @author <a href="mailto:pholser@alumni.rice.edu">Paul Holser</a>
 * @version $Id: ObjectAssert.java,v 1.3 2008/03/30 03:07:11 pholser Exp $
 */
public class ObjectAssert {
    /**
     * Discourages instantiation.
     *
     * @throws UnsupportedOperationException always
     */
    protected ObjectAssert() {
        throw new UnsupportedOperationException();
    }

    /**
     * Asserts that a given object satisfies a given constraint.
     *
     * @param <T> a restriction on the type of the target object
     * @param target the object to query
     * @param constraint the constraint that {@code target} must satisfy
     * @throws junit.framework.AssertionFailedError if the constraint is not satisfied
     * @see <a href="http://joe.truemesh.com/blog/000511.html">Flexible JUnit assertions
     * with <code>assertThat()</code></a>
     */
    public static <T> void assertThat( T target, UnaryPredicate<? super T> constraint ) {
        if ( !constraint.matches( target ) )
            fail( format(
                "expected: <%1$s> but got: <%2$s>", constraint.describe(), target ) );
    }
}
